<?php
// Required headers
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: PUT");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Include database and object files
include_once '../../config/database.php';
include_once '../../models/Patient.php';

// Get database connection
$database = new Database();
$db = $database->getConnection();

// Initialize patient object
$patient = new Patient($db);

// Get posted data
$data = json_decode(file_get_contents("php://input"));

// Make sure id is not empty
if(!empty($data->patient_id)) {
    // Set ID property of patient to be updated
    $patient->patient_id = $data->patient_id;
    
    // Set patient property values
    $patient->full_name = $data->full_name;
    $patient->email = $data->email;
    $patient->gender = $data->gender;
    $patient->date_of_birth = $data->date_of_birth;
    $patient->phone_number = $data->phone_number;
    $patient->emergency_contact_name = $data->emergency_contact_name ?? null;
    $patient->emergency_contact_phone = $data->emergency_contact_phone ?? null;
    $patient->city = $data->city ?? null;
    $patient->region = $data->region ?? null;
    $patient->country = $data->country ?? null;
    $patient->relation_to_client = $data->relation_to_client ?? null;
    $patient->is_account_created_for_relation = $data->is_account_created_for_relation ?? false;
    $patient->selected_service = $data->selected_service ?? null;
    $patient->service_duration = $data->service_duration ?? 'Monthly';
    $patient->shift = $data->shift ?? null;
    $patient->current_conditions = $data->current_conditions ?? null;
    $patient->total_cost = $data->total_cost ?? 0.00;

    // Update the patient
    if($patient->update()) {
        // Set response code - 200 ok
        http_response_code(200);

        // Tell the user
        echo json_encode(array("message" => "Patient was updated."));
    } else {
        // Set response code - 503 service unavailable
        http_response_code(503);

        // Tell the user
        echo json_encode(array("message" => "Unable to update patient."));
    }
} else {
    // Set response code - 400 bad request
    http_response_code(400);

    // Tell the user
    echo json_encode(array("message" => "Unable to update patient. ID is required."));
}
?> 