<?php
class Patient {
    private $conn;
    private $table_name = "patients";

    public $patient_id;
    public $full_name;
    public $email;
    public $password_hash;
    public $gender;
    public $date_of_birth;
    public $phone_number;
    public $emergency_contact_name;
    public $emergency_contact_phone;
    public $city;
    public $region;
    public $country;
    public $relation_to_client;
    public $is_account_created_for_relation;
    public $selected_service;
    public $service_duration;
    public $shift;
    public $current_conditions;
    public $total_cost;

    public function __construct($db) {
        $this->conn = $db;
    }

    // Create new patient
    public function create() {
        $query = "INSERT INTO " . $this->table_name . "
                SET
                    full_name = :full_name,
                    email = :email,
                    password_hash = :password_hash,
                    gender = :gender,
                    date_of_birth = :date_of_birth,
                    phone_number = :phone_number,
                    emergency_contact_name = :emergency_contact_name,
                    emergency_contact_phone = :emergency_contact_phone,
                    city = :city,
                    region = :region,
                    country = :country,
                    relation_to_client = :relation_to_client,
                    is_account_created_for_relation = :is_account_created_for_relation,
                    selected_service = :selected_service,
                    service_duration = :service_duration,
                    shift = :shift,
                    current_conditions = :current_conditions,
                    total_cost = :total_cost";

        $stmt = $this->conn->prepare($query);

        // Sanitize input
        $this->full_name = htmlspecialchars(strip_tags($this->full_name));
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->password_hash = password_hash($this->password_hash, PASSWORD_DEFAULT);
        $this->gender = htmlspecialchars(strip_tags($this->gender));
        $this->date_of_birth = htmlspecialchars(strip_tags($this->date_of_birth));
        $this->phone_number = htmlspecialchars(strip_tags($this->phone_number));
        $this->emergency_contact_name = htmlspecialchars(strip_tags($this->emergency_contact_name));
        $this->emergency_contact_phone = htmlspecialchars(strip_tags($this->emergency_contact_phone));
        $this->city = htmlspecialchars(strip_tags($this->city));
        $this->region = htmlspecialchars(strip_tags($this->region));
        $this->country = htmlspecialchars(strip_tags($this->country));
        $this->relation_to_client = htmlspecialchars(strip_tags($this->relation_to_client));
        $this->selected_service = htmlspecialchars(strip_tags($this->selected_service));
        $this->service_duration = htmlspecialchars(strip_tags($this->service_duration));
        $this->shift = htmlspecialchars(strip_tags($this->shift));
        $this->current_conditions = htmlspecialchars(strip_tags($this->current_conditions));

        // Bind values
        $stmt->bindParam(":full_name", $this->full_name);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":password_hash", $this->password_hash);
        $stmt->bindParam(":gender", $this->gender);
        $stmt->bindParam(":date_of_birth", $this->date_of_birth);
        $stmt->bindParam(":phone_number", $this->phone_number);
        $stmt->bindParam(":emergency_contact_name", $this->emergency_contact_name);
        $stmt->bindParam(":emergency_contact_phone", $this->emergency_contact_phone);
        $stmt->bindParam(":city", $this->city);
        $stmt->bindParam(":region", $this->region);
        $stmt->bindParam(":country", $this->country);
        $stmt->bindParam(":relation_to_client", $this->relation_to_client);
        $stmt->bindParam(":is_account_created_for_relation", $this->is_account_created_for_relation);
        $stmt->bindParam(":selected_service", $this->selected_service);
        $stmt->bindParam(":service_duration", $this->service_duration);
        $stmt->bindParam(":shift", $this->shift);
        $stmt->bindParam(":current_conditions", $this->current_conditions);
        $stmt->bindParam(":total_cost", $this->total_cost);

        if($stmt->execute()) {
            return true;
        }
        return false;
    }

    // Read all patients
    public function read() {
        $query = "SELECT * FROM " . $this->table_name;
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        return $stmt;
    }

    // Read single patient
    public function readOne() {
        $query = "SELECT * FROM " . $this->table_name . " WHERE patient_id = ? LIMIT 0,1";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->patient_id);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        if($row) {
            $this->full_name = $row['full_name'];
            $this->email = $row['email'];
            $this->gender = $row['gender'];
            $this->date_of_birth = $row['date_of_birth'];
            $this->phone_number = $row['phone_number'];
            $this->emergency_contact_name = $row['emergency_contact_name'];
            $this->emergency_contact_phone = $row['emergency_contact_phone'];
            $this->city = $row['city'];
            $this->region = $row['region'];
            $this->country = $row['country'];
            $this->relation_to_client = $row['relation_to_client'];
            $this->is_account_created_for_relation = $row['is_account_created_for_relation'];
            $this->selected_service = $row['selected_service'];
            $this->service_duration = $row['service_duration'];
            $this->shift = $row['shift'];
            $this->current_conditions = $row['current_conditions'];
            $this->total_cost = $row['total_cost'];
            return true;
        }
        return false;
    }

    // Update patient
    public function update() {
        $query = "UPDATE " . $this->table_name . "
                SET
                    full_name = :full_name,
                    email = :email,
                    gender = :gender,
                    date_of_birth = :date_of_birth,
                    phone_number = :phone_number,
                    emergency_contact_name = :emergency_contact_name,
                    emergency_contact_phone = :emergency_contact_phone,
                    city = :city,
                    region = :region,
                    country = :country,
                    relation_to_client = :relation_to_client,
                    is_account_created_for_relation = :is_account_created_for_relation,
                    selected_service = :selected_service,
                    service_duration = :service_duration,
                    shift = :shift,
                    current_conditions = :current_conditions,
                    total_cost = :total_cost
                WHERE
                    patient_id = :patient_id";

        $stmt = $this->conn->prepare($query);

        // Sanitize input
        $this->full_name = htmlspecialchars(strip_tags($this->full_name));
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->gender = htmlspecialchars(strip_tags($this->gender));
        $this->date_of_birth = htmlspecialchars(strip_tags($this->date_of_birth));
        $this->phone_number = htmlspecialchars(strip_tags($this->phone_number));
        $this->emergency_contact_name = htmlspecialchars(strip_tags($this->emergency_contact_name));
        $this->emergency_contact_phone = htmlspecialchars(strip_tags($this->emergency_contact_phone));
        $this->city = htmlspecialchars(strip_tags($this->city));
        $this->region = htmlspecialchars(strip_tags($this->region));
        $this->country = htmlspecialchars(strip_tags($this->country));
        $this->relation_to_client = htmlspecialchars(strip_tags($this->relation_to_client));
        $this->selected_service = htmlspecialchars(strip_tags($this->selected_service));
        $this->service_duration = htmlspecialchars(strip_tags($this->service_duration));
        $this->shift = htmlspecialchars(strip_tags($this->shift));
        $this->current_conditions = htmlspecialchars(strip_tags($this->current_conditions));
        $this->patient_id = htmlspecialchars(strip_tags($this->patient_id));

        // Bind values
        $stmt->bindParam(":full_name", $this->full_name);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":gender", $this->gender);
        $stmt->bindParam(":date_of_birth", $this->date_of_birth);
        $stmt->bindParam(":phone_number", $this->phone_number);
        $stmt->bindParam(":emergency_contact_name", $this->emergency_contact_name);
        $stmt->bindParam(":emergency_contact_phone", $this->emergency_contact_phone);
        $stmt->bindParam(":city", $this->city);
        $stmt->bindParam(":region", $this->region);
        $stmt->bindParam(":country", $this->country);
        $stmt->bindParam(":relation_to_client", $this->relation_to_client);
        $stmt->bindParam(":is_account_created_for_relation", $this->is_account_created_for_relation);
        $stmt->bindParam(":selected_service", $this->selected_service);
        $stmt->bindParam(":service_duration", $this->service_duration);
        $stmt->bindParam(":shift", $this->shift);
        $stmt->bindParam(":current_conditions", $this->current_conditions);
        $stmt->bindParam(":total_cost", $this->total_cost);
        $stmt->bindParam(":patient_id", $this->patient_id);

        if($stmt->execute()) {
            return true;
        }
        return false;
    }

    // Delete patient
    public function delete() {
        $query = "DELETE FROM " . $this->table_name . " WHERE patient_id = ?";
        $stmt = $this->conn->prepare($query);
        $this->patient_id = htmlspecialchars(strip_tags($this->patient_id));
        $stmt->bindParam(1, $this->patient_id);

        if($stmt->execute()) {
            return true;
        }
        return false;
    }
}
?> 